@@ -14,7 +14,7 @@
 #'
 #' The argument `calculate_TL_dose` provides the possibility to experimentally calculate a TL-dose,
 #' i.e. an apparent dose value derived from the TL curve ratio. However, it should be noted that
-#' this value is only a fallback in case something went wrong during the measurement of the optical
+#' this value is only a fall back in case something went wrong during the measurement of the optical
 #' stimulation. The TL derived dose value is corrected for cross-talk and for the irradiation time,
 #' but not considered if a travel dosimeter is defined.
 #'
@@ -27,7 +27,7 @@
 #'
 #' `stimulation_power` [numeric] (default: `0.05`):
 #'
-#' So far available, information on the delievered optical stimulation are compared. Compared are
+#' So far available, information on the delivered optical stimulation are compared. Compared are
 #' the information from the first curves with all others. If the ratio differs more from
 #' unity than the defined by the threshold, a warning is returned.
 #'
@@ -48,14 +48,14 @@
 #' function [get_RLum]. To deactivate the automatic selection set the argument to `NULL`
 #'
 #' @param irradiation_time_correction [numeric] or [RLum.Results-class] (*optional*):
-#' information on the used irradiation time correction obained by another experiements.
+#' information on the used irradiation time correction obtained by another experiments.
 #' I a `numeric` is provided it has to be of length two: mean, standard error
 #'
 #' @param calculate_TL_dose [logical] (*with default*): Enables/disables experimental dose estimation
 #' based on the TL curves. Taken is the ratio of the peak sums of each curves +/- 5 channels.
 #'
 #' @param cross_talk_correction [numeric] or [RLum.Results-class] (*optional*):
-#' information on the used irradiation time correction obained by another experiements.
+#' information on the used irradiation time correction obtained by another experiments.
 #' If a `numeric` vector is provided it has to be of length three:
 #' mean, 2.5 % quantile, 97.5 % quantile.
 #'
@@ -90,7 +90,7 @@
 #'  **Element** \tab **Type** \tab **Description**\cr
 #'  `$data` \tab `data.frame` \tab the estimated equivalent dose \cr
 #'  `$data_table` \tab `data.frame` \tab full dose and signal table \cr
-#'  `test_parameters` \tab `data.frame` \tab results with test paramaters \cr
+#'  `test_parameters` \tab `data.frame` \tab results with test parameters \cr
 #'  `data_TDcorrected` \tab `data.frame` \tab travel dosimeter corrected results (only if TD was provided)\cr
 #' }
 #'
@@ -111,7 +111,7 @@
 #'
 #' @section Function version: 0.2.5
 #'
-#' @author Sebastian Kreutzer, IRAMAT-CRP2A, UMR 5060, CNRS - Université Bordeaux Montaigne (France)
+#' @author Sebastian Kreutzer, Geography & Earth Sciences, Aberystwyth University (United Kingdom)
 #'
 #' @seealso [analyse_Al2O3C_ITC]
 #'
@@ -119,7 +119,7 @@
 #'
 #' Kreutzer, S., Martin, L., Guérin, G., Tribolo, C., Selva, P., Mercier, N., 2018. Environmental Dose Rate
 #' Determination Using a Passive Dosimeter: Techniques and Workflow for alpha-Al2O3:C Chips.
-#' Geochromometria 45, 56-67. \doi{10.1515/geochr-2015-0086}
+#' Geochronometria 45, 56-67.
 #'
 #' @keywords datagen
 #'
@@ -249,15 +249,18 @@ analyse_Al2O3C_Measurement <- function(
     if(!is.null(travel_dosimeter)){
       ##check data type
       if(!is(travel_dosimeter, "numeric"))
-        stop("[analyse_Al2O3C_Measurement()] Input for `travel_dosimeter` is not numeric!", call. = FALSE)
+        stop("[analyse_Al2O3C_Measurement()] Input for `travel_dosimeter` is not numeric!",
+             call. = FALSE)
 
       ##check whether everything is subtracted from everything ... you never know, users do weird stuff
       if(length(travel_dosimeter) == nrow(results$data))
-        try(stop("[analyse_Al2O3C_Measurement()] You specified every position as travel dosimeter, nothing corrected!", call. = FALSE))
+        try(stop("[analyse_Al2O3C_Measurement()] You specified every position as travel dosimeter, nothing corrected!",
+                 call. = FALSE))
 
       ##check if the position is valid
       if(!any(travel_dosimeter%in%results$data$POSITION))
-        try(stop("[analyse_Al2O3C_Measurement()] Invalid position in 'travel_dosimeter', nothing corrected!", call. = FALSE))
+        try(stop("[analyse_Al2O3C_Measurement()] Invalid position in 'travel_dosimeter', nothing corrected!",
+                 call. = FALSE))
 
       ##correct for the travel dosimeter calculating the weighted mean and the sd (as new error)
       ##if only one value is given just take it
@@ -299,7 +302,7 @@ analyse_Al2O3C_Measurement <- function(
 
   }
 
-  # Integretiy check  ---------------------------------------------------------------------------
+  # Integrity check  ---------------------------------------------------------------------------
 
   ##TODO ... do more, push harder
   ##Add sufficient unit tests
