@@ -5,18 +5,23 @@
 #'
 #' The easiest way to create a user-specific layout definition is perhaps to
 #' create either an empty or a default layout object and fill/modify the
-#' definitions (\code{user.layout <- get_Layout(data = "empty")}).
+#' definitions (`user.layout <- get_Layout(data = "empty")`).
 #'
-#' @param layout \code{\link{character}} or \code{\link{list}} object
-#' (required): name of the layout definition to be returned. If name is
-#' provided the respective definition is returned. One of the following
-#' supported layout definitions is possible: \code{"default"},
-#' \code{"journal.1"}, \code{"small"}, \code{"empty"}. User-specific layout
-#' definitions must be provided as a list object of predefined structure, see
-#' details.
+#' @param layout [character] or [list] object (**required**): 
+#' name of the layout definition to be returned. If name is provided the 
+#' respective definition is returned. One of the following
+#' supported layout definitions is possible: `"default"`,
+#' `"journal.1"`, `"small"`, `"empty"`. 
+#' 
+#' User-specific layout definitions must be provided as a list object of
+#' predefined structure, see details.
+#' 
 #' @return A list object with layout definitions for plot functions.
+#' 
 #' @section Function version: 0.1
+#' 
 #' @author Michael Dietze, GFZ Potsdam (Germany)
+#' 
 #' @examples
 #'
 #' ## read example data set
@@ -40,6 +45,7 @@
 #' plot_AbanicoPlot(data = ExampleData.DeValues,
 #'                  layout = "journal")
 #'
+#' @md
 #' @export
 get_Layout <- function(
   layout
@@ -217,7 +223,8 @@ get_Layout <- function(
             value.dot       = numeric(1),  # De value dot colour
             value.bar       = numeric(1),  # De value error bar colour
             value.rug       = numeric(1),  # De value rug colour
-            boxplot         = numeric(1),  # boxplot colour
+            boxplot.line    = numeric(1), # boxplot line colour
+            boxplot.fill    = numeric(1), # boxplot fill colour
             mean.line       = numeric(1),  # mean line colour
             sd.bar          = numeric(1),  # sd-line colour
             background      = numeric(1)), # background colour
@@ -403,13 +410,14 @@ get_Layout <- function(
             ytck2  = 1, # secondary y-axis tick colour
             box    = 1, # plot frame box line colour
             mtext  = 2, # subheader text colour
-            stats  = "#2062B3", # statistic summary colour
-            kde.line        = "#2062B3", # KDE line colour
+            stats  = 1, # statistic summary colour
+            kde.line        = 1, # KDE line colour
             kde.fill        = NULL, # KDE fill colour
             value.dot       = 1, # De value dot colour
             value.bar       = 1, # De value error bar colour
             value.rug       = 1, # De value rug colour
-            boxplot         = 1, # boxplot colour
+            boxplot.line    = 1, # boxplot line colour
+            boxplot.fill    = NULL, # boxplot fill colour
             mean.point       = 1, # mean line colour
             sd.line          = 1, # sd bar colour
             background      = NULL), # background colour
@@ -602,7 +610,8 @@ get_Layout <- function(
             value.dot       = 1, # De value dot colour
             value.bar       = 1, # De value error bar colour
             value.rug       = 1, # De value rug colour
-            boxplot         = 1, # boxplot colour
+            boxplot.line    = 1, # boxplot line colour
+            boxplot.fill    = NULL, # boxplot fill colour
             mean.line       = adjustcolor(col = 1, 
                                           alpha.f = 0.4), # mean line colour
             sd.bar          = adjustcolor(col = 1, 
@@ -641,3 +650,4 @@ get_Layout <- function(
   ## return layout parameters
   return(layout)
 }
+
