@@ -1,13 +1,16 @@
-#' Plot function for an RLum.Data.Spectrum S4 class object
+#' @title Plot function for an RLum.Data.Spectrum S4 class object
 #'
-#' The function provides a standardised plot output for spectrum data of an
-#' RLum.Data.Spectrum S4 class object
+#' @description  The function provides a standardised plot output for spectrum data of an
+#' [RLum.Data.Spectrum-class] class object. The purpose of this function is to provide
+#' easy and straight-forward spectra plotting, not provide a full customised access to
+#' all plot parameters. If this is wanted, standard R plot functionality should be used
+#' instead.
 #'
 #' **Matrix structure** \cr (cf. [RLum.Data.Spectrum-class])
 #'
-#' - `rows` (x-values): wavelengths/channels (xlim, xlab)
-#' - `columns` (y-values): time/temperature (ylim, ylab)
-#' - `cells` (z-values): count values (zlim, zlab)
+#' - `rows` (x-values): wavelengths/channels (`xlim`, `xlab`)
+#' - `columns` (y-values): time/temperature (`ylim`, `ylab`)
+#' - `cells` (z-values): count values (`zlim`, `zlab`)
 #'
 #' *Note: This nomenclature is valid for all plot types of this function!*
 #'
@@ -24,7 +27,7 @@
 #'
 #'**`plot.type = "persp"`**
 #'
-#' Arguments that will be passed to [persp]:
+#' Arguments that will be passed to [graphics::persp]:
 #'
 #' - `shade`: default is `0.4`
 #' - `phi`: default is `15`
@@ -45,6 +48,14 @@
 #'
 #' All frames plotted in one frame.
 #'
+#' '**`plot.type = "image"` or `plot.type = "contour" **
+#'
+#' These plot types use the R functions [graphics::image] or [graphics::contour].
+#' The advantage is that many plots can be arranged conveniently using standard
+#' R plot functionality. If `plot.type = "image"` a contour is added by default,
+#' which can be disabled using the argument `contour = FALSE` to add own contour
+#' lines of choice.
+#'
 #'**`plot.type = "transect"`**
 #'
 #' Depending on the selected wavelength/channel range a transect over the
@@ -57,20 +68,22 @@
 #' **Further arguments that will be passed (depending on the plot type)**
 #'
 #' `xlab`, `ylab`, `zlab`, `xlim`, `ylim`,
-#' `zlim`, `main`, `mtext`, `pch`, `type` ("single", "multiple.lines", "interactive"),
-#' `col`, `border`, `box` `lwd`, `bty`, `showscale` ("interactive")
+#' `zlim`, `main`, `mtext`, `pch`, `type` (`"single"`, `"multiple.lines"`, `"interactive"`),
+#' `col`, `border`, `box` `lwd`, `bty`, `showscale` (`"interactive"`, `"image"`)
+#' `contour`, `contour.col` (`"image"`)
 #'
 #' @param object [RLum.Data.Spectrum-class] or [matrix] (**required**):
 #' S4 object of class `RLum.Data.Spectrum` or a `matrix` containing count
 #' values of the spectrum.\cr
-#' Please note that in case of a matrix rownames and colnames are set
+#' Please note that in case of a matrix row names and col names are set
 #' automatically if not provided.
 #'
 #' @param par.local [logical] (*with default*):
 #' use local graphical parameters for plotting, e.g. the plot is shown in one column and one row.
 #' If `par.local = FALSE` global parameters are inherited.
+#'
 #' @param plot.type [character] (*with default*): plot type, for
-#' 3D-plot use `persp`, or `interactive`, for a 2D-plot `contour`,
+#' 3D-plot use `persp`, or `interactive`, for a 2D-plot `image`, `contour`,
 #' `single` or `multiple.lines` (along the time or temperature axis)
 #' or `transect` (along the wavelength axis) \cr
 #'
@@ -117,27 +130,32 @@
 #' @param xaxis.energy [logical] (*with default*): enables or disables energy instead of
 #' wavelength axis. For the conversion the function [convert_Wavelength2Energy] is used.
 #'
-#' **Note:** This option means not only simnply redrawing the axis,
+#' **Note:** This option means not only simply redrawing the axis,
 #' instead the spectrum in terms of intensity is recalculated, s. details.
 #'
 #' @param legend.text [character] (*with default*):
-#' possiblity to provide own legend text. This argument is only considered for
+#' possibility to provide own legend text. This argument is only considered for
 #' plot types providing a legend, e.g. `plot.type="transect"`
 #'
+#' @param plot [logical] (*with default*): enables/disables plot output. If the plot
+#' output is disabled, the [matrix] used for the plotting and the calculated colour values
+#' (as attributes) are returned. This way, the (binned, transformed etc.) output can
+#' be used in other functions and packages, such as plotting with the package `'plot3D'`
+#'
 #' @param ... further arguments and graphical parameters that will be passed
 #' to the `plot` function.
 #'
-#' @return Returns a plot.
+#' @return Returns a plot if `plot = TRUE`, the default. If `plot = FALSE` the transformed matrix
+#' used for plotting is returned instead.
 #'
 #' @note Not all additional arguments (`...`) will be passed similarly!
 #'
-#' @section Function version: 0.6.2
+#' @section Function version: 0.6.4
 #'
 #' @author
-#' Sebastian Kreutzer, IRAMAT-CRP2A, UMR 5060, CNRS - Université Bordeaux Montaigne (France)
+#' Sebastian Kreutzer, Geography & Earth Sciences, Aberystwyth University (United Kingdom)
 #'
-#' @seealso [RLum.Data.Spectrum-class], [convert_Wavelength2Energy], [plot], [plot_RLum], [persp],
-#' [plotly::plot_ly], [contour]
+#' @seealso [RLum.Data.Spectrum-class], [convert_Wavelength2Energy], [plot], [plot_RLum], [graphics::persp], [plotly::plot_ly], [graphics::contour], [graphics::image]
 #'
 #' @keywords aplot
 #'
@@ -146,13 +164,14 @@
 #' ##load example data
 #' data(ExampleData.XSYG, envir = environment())
 #'
-#' ##(1)plot simple spectrum (2D) - contour
-#' plot_RLum.Data.Spectrum(TL.Spectrum,
-#'                         plot.type="contour",
-#'                         xlim = c(310,750),
-#'                         ylim = c(0,300),
-#'                         bin.rows=10,
-#'                         bin.cols = 1)
+#' ##(1)plot simple spectrum (2D) - image
+#' plot_RLum.Data.Spectrum(
+#'  TL.Spectrum,
+#'  plot.type="image",
+#'  xlim = c(310,750),
+#'  ylim = c(0,300),
+#'  bin.rows=10,
+#'  bin.cols = 1)
 #'
 #' ##(2) plot spectrum (3D)
 #' plot_RLum.Data.Spectrum(
@@ -202,10 +221,6 @@
 #'  type = "heatmap",
 #'  showscale = TRUE)
 #'
-#'  ##(7) alternative using the package fields
-#'  fields::image.plot(get_RLum(TL.Spectrum))
-#'  contour(get_RLum(TL.Spectrum), add = TRUE)
-#'
 #' }
 #'
 #' @md
@@ -224,6 +239,7 @@ plot_RLum.Data.Spectrum <- function(
   limit_counts = NULL,
   xaxis.energy = FALSE,
   legend.text,
+  plot = TRUE,
   ...
 ){
 
@@ -378,7 +394,6 @@ plot_RLum.Data.Spectrum <- function(
   {FALSE}
 
 
-
   # prepare values for plot ---------------------------------------------------
   ##copy data
   temp.xyz <- object@data
@@ -552,7 +567,6 @@ plot_RLum.Data.Spectrum <- function(
 
   }
 
-
   # Normalise if wanted -------------------------------------------------------------------------
   if(!is.null(norm)){
     if(norm == "min")
@@ -568,10 +582,8 @@ plot_RLum.Data.Spectrum <- function(
   zlim <- if("zlim" %in% names(extraArgs)) {extraArgs$zlim} else
   {range(temp.xyz)}
 
-
-  # set color values --------------------------------------------------------
+  # set colour values --------------------------------------------------------
   if("col" %in% names(extraArgs) == FALSE | plot.type == "single" | plot.type == "multiple.lines"){
-
     if(optical.wavelength.colours == TRUE | (rug == TRUE & (plot.type != "persp" & plot.type != "interactive"))){
 
       ##make different colour palette for energy values
@@ -585,7 +597,6 @@ plot_RLum.Data.Spectrum <- function(
         col.infrared <-
           c(1.55, ifelse(min(xlim) >= 1.55, min(xlim), 1.57))
 
-
         #set colour palette
         col <- unlist(sapply(1:length(x), function(i){
 
@@ -705,11 +716,10 @@ plot_RLum.Data.Spectrum <- function(
   ##z
   if(grepl("z", log)==TRUE){temp.xyz <- log10(temp.xyz)}
 
-
-  # PLOT --------------------------------------------------------------------
-
+# PLOT --------------------------------------------------------------------
+if(plot){
   ##par setting for possible combination with plot method for RLum.Analysis objects
-  if(par.local == TRUE){par(mfrow=c(1,1), cex = cex)}
+  if(par.local) par(mfrow=c(1,1), cex = cex)
 
   ##rest plot type for 1 column matrix
   if(ncol(temp.xyz) == 1 && plot.type != "single"){
@@ -725,10 +735,9 @@ plot_RLum.Data.Spectrum <- function(
   }
 
   if(plot.type == "persp" && ncol(temp.xyz) > 1){
+    ## Plot: perspective plot ----
     ## ==========================================================================#
-    ##perspective plot
-    ## ==========================================================================#
-    persp(x, y, temp.xyz,
+    pmat <- persp(x, y, temp.xyz,
           shade = shade,
           phi = phi,
           theta = theta,
@@ -745,6 +754,7 @@ plot_RLum.Data.Spectrum <- function(
           r = r,
           ticktype = ticktype)
 
+
     ##plot additional mtext
     mtext(mtext, side = 3, cex = cex*0.8)
 
@@ -793,34 +803,48 @@ plot_RLum.Data.Spectrum <- function(
 
 
   }else if(plot.type == "contour" && ncol(temp.xyz) > 1) {
-    ## ==========================================================================#
-    ##contour plot
+    ## Plot: contour plot ----
     ## ==========================================================================#
     contour(x,y,temp.xyz,
             xlab = xlab,
             ylab = ylab,
             main = main,
+            labcex = 0.6 * cex,
             col = "black"
     )
 
     ##plot additional mtext
     mtext(mtext, side = 3, cex = cex*0.8)
 
+  }else if(plot.type == "image" && ncol(temp.xyz) > 1) {
+    ## Plot: image plot ----
+    ## ==========================================================================#
+    graphics::image(x,y,temp.xyz,
+            xlab = xlab,
+            ylab = ylab,
+            main = main,
+            col = if(is.null(list(...)$col)) grDevices::hcl.colors(50, palette = "Inferno") else
+              list(...)$col
+    )
+
+    if(is.null(list(...)$contour) || list(...)$contour != FALSE) {
+      contour(x, y, temp.xyz,
+              col = if(is.null(list(...)$contour.col)) rgb(1,1,1,0.8) else list(...)$contour.col,
+              labcex = 0.6 * cex,
+              add = TRUE)
+    }
+
+    ##plot additional mtext
+    mtext(mtext, side = 3, cex = cex*0.8)
 
   } else if(plot.type == "single") {
-    ## ==========================================================================#
-    ## single plot
+    ## Plot: single plot ----
     ## ==========================================================================#
 
     col.rug <- col
-
-    col<- if("col" %in% names(extraArgs)) {extraArgs$col} else
-    {"black"}
-
-
+    col<- if("col" %in% names(extraArgs)) {extraArgs$col} else {"black"}
 
     for(i in 1:length(y)){
-
       if("zlim" %in% names(extraArgs) == FALSE){zlim <- range(temp.xyz[,i])}
 
       plot(x, temp.xyz[,i],
@@ -856,12 +880,10 @@ plot_RLum.Data.Spectrum <- function(
 
 
   }else if(plot.type == "multiple.lines" && ncol(temp.xyz) > 1) {
-    ## ========================================================================#
-    ## multiple.lines plot
+    ## Plot: multiple.lines ----
     ## ========================================================================#
 
     col.rug <- col
-
     col<- if("col" %in% names(extraArgs)) {extraArgs$col} else
     {"black"}
 
@@ -928,8 +950,7 @@ plot_RLum.Data.Spectrum <- function(
     rm(par.default)
 
   }else if(plot.type == "transect" && ncol(temp.xyz) > 1) {
-    ## ========================================================================#
-    ## transect plot
+    ## Plot: transect plot ----
     ## ========================================================================#
 
     ##sum up rows (column sum)
@@ -962,6 +983,14 @@ plot_RLum.Data.Spectrum <- function(
   }else{
     stop("[plot_RLum.Data.Spectrum()] Unknown plot type.", call. = FALSE)
 
-  }
+ }
+
+## option for plotting nothing
+} else {
+  ## if nothing is plotted return the transformed plot object
+  attr(temp.xyz, "colour") <- col
+  return(temp.xyz)
+
+}
 
 }
