@@ -1,5 +1,3 @@
-context("calc_AverageDose")
-
 data(ExampleData.DeValues, envir = environment())
 temp <- calc_AverageDose(ExampleData.DeValues$CA1[1:56,],
                        sigma_m = 0.1,
@@ -8,13 +6,17 @@ temp <- calc_AverageDose(ExampleData.DeValues$CA1[1:56,],
 
 test_that("check class and length of output", {
   testthat::skip_on_cran()
-  expect_equal(is(temp), c("RLum.Results", "RLum"))
+  local_edition(3)
+
+  expect_s4_class(temp, "RLum.Results")
   expect_equal(length(temp), 3)
 
 })
 
 test_that("check summary output", {
   testthat::skip_on_cran()
+  local_edition(3)
+
   results <- get_RLum(temp)
 
   expect_equal(round(results$AVERAGE_DOSE, digits = 4), 65.3597)
